logbinsearch
================

search log file with binary search.

decompress BZ2 file by block.

Usage::

```
    $ pip install logbinsearch
    $ logdatetimesearch -h
    $ logdatetimesearch --from='2015-01-10 12:52:00' --to='2015-01-10 12:58:00' path/to/log
```

